package com.ua.connections.gui;

import com.sun.glass.ui.Screen;
import com.ua.connections.modem.Modem;
import com.ua.connections.states.ApplicationState;
import com.ua.connections.wifi.WiFi;
import com.utils.encoding.UTF8Control;
import javafx.animation.Animation;
import javafx.animation.KeyFrame;
import javafx.animation.Timeline;
import javafx.animation.TimelineBuilder;
import javafx.application.Application;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;

import javafx.geometry.Pos;
import javafx.scene.Cursor;
import javafx.scene.Group;
import javafx.scene.Scene;
import javafx.scene.control.*;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.TextArea;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.*;
import javafx.scene.paint.Color;
import javafx.stage.Stage;
import javafx.templates.header.Header;
import javafx.templates.lang.LanguageLocal;
import javafx.templates.messages.ErrorMonitor;
import javafx.util.Duration;
import javafx.templates.footer.Footer;
import javafx.templates.initScreen.Initializer;

import java.util.ResourceBundle;


/**
 * Created by Oxana on 3/9/15.
 */
public class MainScreen extends Application {

    public static Group root;
    private static Timeline watchTimer;
    private static final int UPDATE_INTERVAL = 10;
    public static int width ;
    public static int height;
    public static Header head;
    static javafx.scene.control.TextArea textArea;
    static javafx.scene.control.TextArea textArea1;
    static TextField portField;
    static TextField nameField;
    public static String namePort="";
    public static String nameWifi="";
    public static ResourceBundle currentLocale;

    public static void getMainSettings(){
        LanguageLocal.initLanguage("resources//local//Locale");
        currentLocale=LanguageLocal.currentLocale;
        root = new Group();
        try {

            root.setOnMouseReleased(new EventHandler<MouseEvent>() {
                public void handle(MouseEvent event) {
                    mouseClicked();
                }
            });
        } catch (Exception ex) {
            ex.printStackTrace();
        }

        watchTimer = TimelineBuilder.create().keyFrames(
                new KeyFrame(Duration.seconds(UPDATE_INTERVAL), "updateScreen",
                        new EventHandler<ActionEvent>() {
                            public synchronized void handle(ActionEvent event) {
                                terminalEvent();
                            }
                        })).build();
        watchTimer.setCycleCount(Animation.INDEFINITE);
        watchTimer.play();


    }


    @Override
    public void start(Stage stage) throws Exception {
        state=ApplicationState.INIT_APPLICATION;
        getMainSettings();
        width= Screen.getMainScreen().getWidth();
        height=Screen.getMainScreen().getHeight();

        Scene scene = new Scene( getRoot());
        scene.setCursor(Cursor.HAND);
        scene.setFill(Color.GREEN);

        stage.setWidth(width);
        stage.setHeight(height);

        stage.setScene(scene);
        stage.setTitle( "Connector Application" );
        stage.setFullScreen( true );
        String css = this.getClass().getResource("/resources/css/main.css").
                toExternalForm();
        stage.getScene().getStylesheets().add(css);
        root.setId("background");
        root.setCache(false);

        stage.show();


    }
    public static void mouseClicked() {

        stopWatchTimer();
        startWatchTimer();
    }
    private static void stopWatchTimer() {

        watchTimer.stop();
    }

    private static void startWatchTimer() {

        watchTimer.playFromStart();
    }

    private static void terminalEvent() {
        switch (state) {
            case WAIT: {
                stopWatchTimer();
                showTerminalMenu();

            }
            break;
            case INPUT_PROCESS: {
            }
            break;
            case INIT_APPLICATION: {
                Initializer.showApplicationInit(root,"Please wait, loading application...");
                state = ApplicationState.WAIT;
                break;
            }
            case ERROR: {
                new ErrorMonitor().showTerminalError(root,"Terminal disabled.");
                break;
            }
        }
    }

    public static Group getRoot() {
        return root;
    }
    public static void showTerminalMenu() {
        root.getChildren().clear();
//$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
       head = javafx.templates.header.Header.getInstance(
                "/resources/images/header/internet.jpg",
                "/resources/images/header/green.png",145,width
                );

        head.getNode().setLayoutX(0);
        head.getNode().setLayoutY(0);
//$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
        VBox container = new VBox(100);
        container.setLayoutX(5);
        container.setLayoutY(145);
        container.setMaxSize(width,height-145- Footer.heightFooter);
        container.setMinSize(width, height - 145 - Footer.heightFooter);
        container.setCache(false);
        container.setSpacing(2);
        container.setId("background");


        TabPane tabPane=new TabPane();
        tabPane.setBackground(new Background(new BackgroundImage(
                new Image("resources//images//header//connection.jpeg"),
                BackgroundRepeat.NO_REPEAT,
                BackgroundRepeat.NO_REPEAT,
                BackgroundPosition.DEFAULT,
                new BackgroundSize(800, height-145- Footer.heightFooter, false, false, false, false))));
//###########################################
        Tab tabModem=new Tab("modem");
        tabModem.setClosable(false);

        HBox hbox=new HBox();
        hbox.setAlignment(Pos.CENTER);
        hbox.setMinSize(800, height-145- Footer.heightFooter);
        hbox.setMaxSize(800, height-145- Footer.heightFooter);

        VBox vbox = new VBox();
        vbox.setMinSize(600, height-145- Footer.heightFooter);
        vbox.setMaxSize(600, height-145- Footer.heightFooter);
        vbox.setAlignment(Pos.CENTER_LEFT);

        Label port=new Label(currentLocale.getString("port"));
        port.setStyle("-fx-background-color: burlywood;-fx-font-weight: bold");
        vbox.getChildren().add(port);

        namePort="COM1";
        portField=new TextField(namePort);
        portField.setEditable(true);
        namePort=portField.getText();

        vbox.getChildren().add(portField);
        Label label=new Label(currentLocale.getString("buttonTestModem"));
        label.setStyle("-fx-background-color: burlywood;-fx-font-weight: bold");
        vbox.getChildren().add(label);

        textArea=new TextArea(currentLocale.getString("results"));
        textArea.setMinSize(600,200);
        textArea.setMaxSize(600,200);
        textArea.setEditable(false);
        vbox.getChildren().add(textArea);

        Button buttonTestModem=new Button("Test modem");
        buttonTestModem.setMinSize(200, 50);
        buttonTestModem.setOnAction(new EventHandler<ActionEvent>() {
            @Override
            public void handle(ActionEvent actionEvent) {
                checkModem();
            }
        });
        vbox.getChildren().add(buttonTestModem);

        VBox vbox1 = new VBox();
        vbox1.setMinSize(150, 200);
        vbox1.setMaxSize(150, 200);
        vbox1.setAlignment(Pos.CENTER);


        ProgressBar progressBar=new ProgressBar();
        progressBar.setMinSize(150, 20);
        progressBar.setMaxSize(150, 20);
        progressBar.setProgress(0.1f);
        vbox1.getChildren().add(progressBar);

        HBox hb=new HBox();
        hb.setMinSize(150, 70);
        hb.setMaxSize(150, 70);
        vbox1.getChildren().add(hb);

        Button getSignalLevel =new Button();
        getSignalLevel.setOnAction(new EventHandler<ActionEvent>() {
                                       @Override
                                       public void handle(ActionEvent actionEvent) {
                                           progressBar.setProgress(Modem.getInstance("COM1").getSpeedConnectionInPercentage());
                                       }
                                   }
        );
        //getSignalLevel.setGraphic(new ImageView("resources//images//modem//level.png"));
        getSignalLevel.setMinSize(150, 50);
        getSignalLevel.setBackground(new Background(new BackgroundImage(
                new Image("resources//images//modem//level.png"),
                BackgroundRepeat.NO_REPEAT,
                BackgroundRepeat.NO_REPEAT,
                BackgroundPosition.DEFAULT,
                new BackgroundSize(150, 50, false, false, false, false))));

        vbox1.getChildren().add(getSignalLevel);
        VBox vbox2 = new VBox();
        vbox2.setMinSize(50, 200);
        vbox2.setMaxSize(50, 200);
        vbox2.setAlignment(Pos.CENTER);

        hbox.getChildren().addAll(vbox,vbox2, vbox1);

        tabModem.setContent(hbox);

        Tab tabWIFI=new Tab("wifi");
        tabWIFI.setClosable(false);
        VBox hbox1=new VBox();
        hbox1.setMinSize(150, 300);
        hbox1.setMaxSize(150, 300);

        Label nameWIFI=new Label(currentLocale.getString("WIFI"));
        nameWIFI.setMinSize(300, 50);
        nameWIFI.setStyle("-fx-background-color: burlywood;-fx-font-weight: bold");
        hbox1.getChildren().add(nameWIFI);

        nameWifi="SGSOFT";
        nameField=new TextField(nameWifi);
        nameField.setMinSize(300, 50);
        nameField.setEditable(true);
        nameWifi=nameField.getText();
        hbox1.getChildren().add(nameField);

        Label label1=new Label(currentLocale.getString("buttonTestWIFI"));
        label1.setStyle("-fx-background-color: burlywood;-fx-font-weight: bold");
        label1.setMinSize(300, 50);
        hbox1.getChildren().add(label1);

        textArea1=new TextArea(currentLocale.getString("results"));
        textArea1.setMinSize(600,200);
        textArea1.setMaxSize(600, 200);
        textArea1.setEditable(false);
        hbox1.getChildren().add(textArea1);

        ProgressBar progressBar1=new ProgressBar();
        progressBar1.setMinSize(150, 20);
        progressBar1.setMaxSize(150, 20);
        progressBar1.setProgress(0.1f);
        hbox1.getChildren().add(progressBar1);

        Button getWIFISignalLevel =new Button();
        getWIFISignalLevel.setOnAction(new EventHandler<ActionEvent>() {
                                       @Override
                                       public void handle(ActionEvent actionEvent) {
                                           WiFi wf=WiFi.getInstance("SGSOFT");
                                           progressBar1.setProgress(
                                                   wf!=null?1:0.1);
                                           textArea1.setText(WiFi.RESULTS.toString());

                                       }
                                   }
        );

        getWIFISignalLevel.setMinSize(150, 50);
        getWIFISignalLevel.setBackground(new Background(new BackgroundImage(
                new Image("resources//images//wifi//wi-fi-on.jpg"),
                BackgroundRepeat.NO_REPEAT,
                BackgroundRepeat.NO_REPEAT,
                BackgroundPosition.DEFAULT,
                new BackgroundSize(150, 100, false, false, false, false))));

        hbox1.getChildren().add(getWIFISignalLevel);

        tabWIFI.setContent(hbox1);

        tabPane.getTabs().addAll(tabModem, tabWIFI);

        container.getChildren().addAll(tabPane);
//$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
        Footer footer = Footer.getInstance(false, false, true, 145,width);
        footer.getNode().setLayoutX(0);
        footer.getNode().setLayoutY(height - Footer.heightFooter);
//$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
        root.getChildren().addAll(
                head.getNode(),
                container,
                footer.getNode()
        );
        setRootMain(root);

    }
    public static void checkModem(){
        namePort=portField.getText();
        Modem modem=Modem.getInstance(namePort);
        modem.testModem();
        textArea.setText(Modem.error.isEmpty()?Modem.response:Modem.error);

    }
    public static void setRootMain(Group rootMain) {
        root = rootMain;
    }
    public static ApplicationState state;
    public static void main(String []args){
        launch(args);
    }
}
