package com.ua.connections.modem;

import com.comp.os.DetectorCompOS;
import com.utils.log.LogWork;
import jssc.SerialPort;
import jssc.SerialPortEvent;
import jssc.SerialPortEventListener;
import jssc.SerialPortException;
import myFiler.MyFiler;
import ua.com.hardware.comp.comport.ComPort;
import ua.com.hardware.modem.ModemTest;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

/**
 * Created by Oxana on 3/10/15.
 */
public class Modem implements ComPortListener, SerialPortEventListener {
    private SerialPort serialPort;
    @Override
    public void serialEvent(SerialPortEvent serialPortEvent) {
        if (serialPortEvent.isRXCHAR()) {
            int eventValue = serialPortEvent.getEventValue();
            if (eventValue != 0) {

                try {
                    int[] incomingData = serialPort.readIntArray();
                    notifyObservers(incomingData);
                } catch (SerialPortException e) {
                    System.out.println("error in reading int array"+e.getMessage());
                    error=error+'\n'+e.getMessage();
                    e.printStackTrace();
                }
            }
        }

    }
    private void notifyObservers(int[] receivingBuffer) {
            fromComPort(receivingBuffer);
    }
    public static String response,error;
    private LogWork modemLog=new LogWork();
    private String modemFile=new String("modemLog.txt");
    @Override
    public void fromComPort(int[] receivingBufferListener) {
        String str = "";

        for(int i=0;i<receivingBufferListener.length;i++){
            str+=(char)receivingBufferListener[i];
        }
		System.out.println("at, str= "+str);

        response=response+"from Modem :"+str;
            return;
        }
    private static Modem modem;
    private String nameComPort="";

    private Modem(String nameComPort) {
        this.nameComPort = nameComPort;
        //comPort=new ComPort(nameComPort);
        if(!modemLog.isOpened() && !modemLog.openFile(this.modemFile).booleanValue()) {
            MyFiler.createFile(MyFiler.getCurrentDirectory() + File.separator + this.modemFile);
        }
        response = "";
        error = "";
        modemLog.writeInFile("initModem");
        initCOMPort(115200, 8, 1, 0);
    }
   private boolean runCmd(String str)throws Exception{
    Runtime rt = Runtime.getRuntime();
    Process p=rt.exec(str);
    BufferedReader br = new BufferedReader(new InputStreamReader(p.getInputStream(), "Cp866"));
    p.waitFor();
    for (int i = 0; i <= 500; i++) {
        String str1 = br.readLine();
        if (str1 == null) {
            continue;
        }
    }
    System.out.println("runInCmd"+p.exitValue());
    return p.exitValue()==0;
}

    public boolean initCOMPort(int baudRate, int dataBits, int stopBits, int parity) {
        if(DetectorCompOS.isUnix()) {
            try {
                runCmd("sudo chmod -R 777 " + nameComPort);
            }
            catch(Exception exc){
                error=error+'\n'+exc.getMessage();
                exc.printStackTrace();}
        }

        serialPort = new SerialPort(nameComPort);
        try {

            if(!serialPort.isOpened()){ serialPort.openPort();}

            serialPort.setParams(baudRate, dataBits, stopBits, parity);

            int mask = SerialPort.MASK_RXCHAR;

            serialPort.setEventsMask(mask);
            serialPort.addEventListener(this);
        } catch (SerialPortException ex) {
            error=error+'\n'+ex.getMessage();
            System.err.println("exception " + nameComPort + " exceprion: " + ex.getMessage());
            return false;
        }
        return true;
    }
    public boolean sendByteCommand(byte[] inpByte) {
        try {
            serialPort.writeBytes(inpByte);
        } catch (SerialPortException e) {
            System.out.println("exception writing sendStringCommand in port: " + e.getMessage());
            e.printStackTrace();
            error=error+'\n'+e.getMessage();
        }
        return true;
    }
    public boolean sendCommandToModem(String command){

        byte[] byteArray=command.getBytes();

        return sendByteCommand(byteArray);

    }
    //$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
    public boolean testModem(){
        boolean ok=false;
        ModemTest.disconnect();

        if(!modemLog.isOpened())
            if(!modemLog.openFile(modemFile))
                MyFiler.createFile(MyFiler.getCurrentDirectory()+ File.separator+modemFile);
        modemLog.writeInFile("start : modemTest");
        response="";
        ok=sendCommandToModem("AT+CGDCONT=1,\"IP\",\"3g.utel.ua\"");
        if(!ok)return ok;
        ok=sendCommandToModem("ati1\r");
        if(!ok)return ok;
        //balanse
        ok=sendCommandToModem("AT+CUSD=1,*100#,15\r");
        if(!ok)return ok;
        ok=sendCommandToModem("AT+CUSD=1,*121#,15\r");
        if(!ok)return ok;
        ok=sendCommandToModem("AT+CUSD=1,*145#,15\r");
        if(!ok)return ok;
        ok=sendCommandToModem("AT+CSQ\r");
        modemLog.writeInFile(response);
        modemLog.writeInFile("finish : modemTest");

        return ok;
    }
    //$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
    public  int balanceModem(){
       int balance=0;
        ModemTest.disconnect();
        //sendCommandToModem("AT+CUSD=1,*100#,15\r");
        balance=Integer.valueOf(ModemTest.getBalanceInDigit());
        return balance;
    }
    //$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
    public float getSpeedConnectionInPercentage(){
        ModemTest.disconnect();
        float percentage=0;
        sendCommandToModem("AT+CSQ\r");
        if(response.contains("+CSQ")) {
            int val = 0;
            String s = "";
            String[] sa = response.split(":");
            if (sa.length >= 2) {
                char[] csa = sa[1].toCharArray();
                for (int i = 0; i < csa.length; i++) {
                    if (csa[i] == ' ') {
                        continue;
                    }
                    if (csa[i] == ',') {
                        break;
                    }
                    s += csa[i];
                }
            }
            val = Integer.parseInt(s);
            System.out.println("contains csq, val=" + val);
            response = response + "from Modem CSQ :" + val + response;
        }
        int indexLevel=response.indexOf("+CSQ:");
        float signal=0.1f;
        if(indexLevel!=-1) {
            String levelString = response.substring(indexLevel + 6);
            String[] levels = levelString.split(",");

            Float lev1 = 0.0f;
            Float lev2 = 0.0f;

            if (levels != null && levels.length >= 2) {
                lev1 = Float.valueOf(levels[0]);
                System.out.println(lev1);
                String[] levels1 = levels[1].split("\n");
                if (levels1 != null && levels1.length > 0) {
                    lev2 = Float.valueOf(levels1[0]);
                }
            }
            signal = ((float) ModemTest.signalLevelPersentGetFromRSSI(lev1) / 100.0f);
        }
         percentage=signal;
        return percentage;
    }
    //$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
    public void setNameComPort(String nameComPort) {
        this.nameComPort = nameComPort;
    }

    public String getNameComPort() {

        return nameComPort;
    }
    public static Modem getInstance(String nameComPort){
        return modem!=null?modem:new Modem(nameComPort);
    }
}
